# MAIN EXHIBITS: Figures and Tables
#
# 

source('code/load.R')



# =================================  FIGURES ==================================# 
# Figure 1
make_participation_bar_graphs = function(data) {
  for (year in 2017:2018) {
    
    # Unpooled
    data = data %>% mutate(treatment_type = ifelse(treatment_main == 1, 'Treatment', ifelse(treatment_subway == 1, 'Placebo', 'Pure control')))
    
    outcome_var = str_interp('participate_july1_${year}')
    takeup = data %>%
      group_by(treatment_type) %>% 
      summarise(mean = weighted.mean(get(outcome_var), w=weight), 
                se = weighted.sd(get(outcome_var), w=weight)/sqrt(n()),
                .groups = 'drop') %>%
      mutate(high = mean+1.96*se, low = mean-1.96*se)
    
    takeup$treatment_type = factor(takeup$treatment_type, levels = c('Pure control','Placebo','Treatment'))
    outcome = ifelse(year==2017, 'participate_july1_2017', 'participate_july1_2018')
    
    
    
    data$treatment_type_pc = as.numeric(data$treatment_type=="Pure control")
    data$treatment_type_pl = as.numeric(data$treatment_type=="Placebo")
    data$treatment_type_tr = as.numeric(data$treatment_type=="Treatment")
    

    # Calculate p-values
    formula = as.formula(str_interp('get(outcome_var)~treatment_type_pl+treatment_type_tr|treatment_cell|0|treatment_cell'))
    model = felm(formula, data=data, weights=data$weight)
    hyp = linearHypothesis(model, c("treatment_type_pl = 0"), test='F', singular.ok = TRUE)
    p1 = hyp$`Pr(>F)`[2] %>% formatP(latex=FALSE,p=TRUE)
    hyp = linearHypothesis(model, c("treatment_type_pl = treatment_type_tr"), test='F', singular.ok = TRUE)
    p2 = hyp$`Pr(>F)`[2] %>% formatP(latex=FALSE,p=TRUE)
    hyp = linearHypothesis(model, c("treatment_type_tr = 0"), test='F', singular.ok = TRUE)
    p3 = hyp$`Pr(>F)`[2] %>% formatP(latex=FALSE,p=TRUE)
    
    
    plot = ggplot(takeup, aes(x = treatment_type, y = mean)) + 
      geom_bar(stat='identity', alpha=0.8, width = 0.5, aes(fill = treatment_type)) +
      ylab('Mean protest participation') + xlab('Treatment group') +
      guides(fill=F) +
      coord_cartesian(ylim=c(0, 0.15)) +
      theme_three

    
    tl = 0.018
    if (year==2017) {
      plot = plot +
        geom_signif(annotation = p1, xmin=1, xmax=2, y_position=0.03, tip_length = tl, textsize=7) +
        geom_signif(annotation = p2, xmin=2, xmax=3, y_position=0.12, tip_length = tl, textsize=7) +
        geom_signif(annotation = p3, xmin=1, xmax=3, y_position=0.135, tip_length = tl, textsize=7)
    } else {
      plot = plot +
        geom_signif(annotation = p1, xmin=1, xmax=2, y_position=0.035, tip_length = tl, textsize=7) +
        geom_signif(annotation = p2, xmin=2, xmax=3, y_position=0.08, tip_length = tl, textsize=7) +
        geom_signif(annotation = p3, xmin=1, xmax=3, y_position=0.095, tip_length = tl, textsize=7)
    }
    ggsave(str_interp('${out}/protest-participation-${year}.pdf'), plot)
    
    # Pooled
    takeup2 = data %>% mutate(treatment_type2 = ifelse(treatment_type == 'Treatment', 'Treatment', 'Control')) 
    
    
 
    
    
    # Calculate p-values
    formula = as.formula(str_interp('get(outcome_var)~treatment_type_tr|treatment_cell|0|treatment_cell'))
    model = felm(formula, data=data, weights=data$weight)
    hyp = linearHypothesis(model, c("treatment_type_tr = 0"), test='F', singular.ok = TRUE)
    p = hyp$`Pr(>F)`[2] %>% formatP(latex=FALSE,p=TRUE)
   
    
    
    outcome_var = str_interp('participate_july1_${year}')
    takeup2 = takeup2 %>%
      group_by(treatment_type2) %>% 
      summarise(mean = weighted.mean(get(outcome_var), w=weight), 
                se = weighted.sd(get(outcome_var), w=weight)/sqrt(n()),
                .groups = 'drop') %>%
      mutate(high = mean+1.96*se, low = mean-1.96*se)
    
    takeup2$treatment_type2 = factor(takeup2$treatment_type2, levels = c('Control','Treatment')) 
    plot = ggplot(takeup2, aes(x = treatment_type2, y = mean)) + 
      geom_bar(stat='identity', alpha=0.8, width = 0.5, aes(fill = treatment_type2)) +
      ylab('Mean protest participation') + xlab('Treatment group') +
      guides(fill=F) +
      coord_cartesian(ylim=c(0, 0.15)) +
      theme_two
    if (year == 2017) {
      plot = plot + 
        geom_signif(annotation=p, xmin=1, xmax=2, y_position=0.12, tip_length = tl, textsize=7)
    } else {
      plot = plot + 
        geom_signif(annotation=p, xmin=1, xmax=2, y_position=0.08, tip_length = tl, textsize=7)
    }
    ggsave(str_interp('${out}/protest-participation-pooled-${year}.pdf'))

    
  }
}


# Figure 2
make_participation_bar_graphs_heterogeneity = function(data) {
  tl = 0.018
  for (year in 2017:2018) {
    
    # Heterogeneity
    data = data %>% mutate(treatment_type = ifelse(treatment_main == 1, 'Treatment', ifelse(treatment_subway == 1, 'Placebo', 'Pure control')))
    takeup2 = data %>% mutate(treatment_type2 = ifelse(treatment_type == 'Treatment', 'Treatment', 'Control')) 
    
    outcome_var = str_interp('participate_july1_${year}')
    
    takeup2$treatment_cell_tier_1 = as.numeric(takeup2$approximate_treatment_cell_tier==0.01)
    takeup2$treatment_cell_tier_0 = as.numeric(takeup2$approximate_treatment_cell_tier==0)
    
    
    # Calculate p-values
    formula = as.formula(str_interp('get(outcome_var)~treatment_cell_tier_1:treatment+treatment_cell_tier_50:treatment+treatment_cell_tier_75:treatment|treatment_cell|0|treatment_cell'))
    model = felm(formula, data=takeup2, weights=takeup2$weight)
    hyp = linearHypothesis(model, c("treatment_cell_tier_1:treatment = 0"), test='F', singular.ok = TRUE)
    p1 = hyp$`Pr(>F)`[2] %>% formatP(latex=FALSE,p=TRUE)
    hyp = linearHypothesis(model, c("treatment:treatment_cell_tier_50 = 0"), test='F', singular.ok = TRUE)
    p2 = hyp$`Pr(>F)`[2] %>% formatP(latex=FALSE,p=TRUE)
    hyp = linearHypothesis(model, c("treatment:treatment_cell_tier_75 = 0"), test='F', singular.ok = TRUE)
    p3 = hyp$`Pr(>F)`[2] %>% formatP(latex=FALSE,p=TRUE)
    hyp = linearHypothesis(model, c("treatment_cell_tier_1:treatment = treatment:treatment_cell_tier_50"), test='F', singular.ok = TRUE)
    p4 = hyp$`Pr(>F)`[2] %>% formatP(latex=TRUE,p=TRUE)
    hyp = linearHypothesis(model, c("treatment_cell_tier_1:treatment = treatment:treatment_cell_tier_75"), test='F', singular.ok = TRUE)
    p5 = hyp$`Pr(>F)`[2] %>% formatP(latex=TRUE,p=TRUE)
    hyp = linearHypothesis(model, c("treatment:treatment_cell_tier_50 = treatment:treatment_cell_tier_75"), test='F', singular.ok = TRUE)
    p6 = hyp$`Pr(>F)`[2] %>% formatP(latex=TRUE,p=TRUE)

    
    # Calculate mean and se
    takeup2 = takeup2 %>%
      group_by(treatment_type2, approximate_treatment_cell_tier) %>% 
      summarise(mean = weighted.mean(get(outcome_var), w=weight), 
                se = weighted.sd(get(outcome_var), w=weight)/sqrt(n()),
                .groups = 'drop') %>%
      mutate(high = mean+1.96*se, low = mean-1.96*se,
             approximate_treatment_cell_tier = dplyr::recode(approximate_treatment_cell_tier,
                                                             `0` = '0%',
                                                             `0.01` = '1%',
                                                             `0.5` = '50%',
                                                             `0.75` = '75%'),
             treatment_type2 = factor(treatment_type2, levels=c('Control','Treatment')))
    
    
    # Drop 0%
    takeup2 = takeup2 %>% filter(approximate_treatment_cell_tier!="0%")


    # Plot 
    plot = ggplot(takeup2, aes(x = approximate_treatment_cell_tier, y=mean)) + 
      geom_bar(stat='identity', position=position_dodge2(width=0.9, preserve='single'), aes(fill = treatment_type2,  color=treatment_type2, y = mean)) + 
      xlab('Cell treatment intensity') + ylab('Proportion participating') +
      labs(fill = 'Condition') +
      scale_x_discrete("Cell treatment intensity", limits = c("1%", "50%", "75%")) +
      guides(color=FALSE) + # Hide legend for outer line of geom_bar
      coord_cartesian(ylim=c(0, 0.15)) +
      theme_two
    if (year == 2017) {
      plot = plot + 
        geom_signif(annotation=p1, xmin=1-0.25, xmax=1+0.25, y_position=0.132, tip_length = tl, textsize=5) +
        geom_signif(annotation=p2, xmin=2-0.25, xmax=2+0.25, y_position=0.118, tip_length = tl, textsize=5) +
        geom_signif(annotation=p3, xmin=3-0.25, xmax=3+0.25, y_position=0.119, tip_length = tl, textsize=5)
    } else {
      plot = plot + 
        geom_signif(annotation=p1, xmin=1-0.25, xmax=1+0.25, y_position=0.036, tip_length = tl, textsize=5) +
        geom_signif(annotation=p2, xmin=2-0.25, xmax=2+0.25, y_position=0.041, tip_length = tl, textsize=5) +
        geom_signif(annotation=p3, xmin=3-0.25, xmax=3+0.25, y_position=0.104, tip_length = tl, textsize=5)}
    
    ggsave(str_interp('${out}/protest-participation-heterogeneity-${year}.pdf'))
  
    
    
    # Create mini-table new
    descriptor = ifelse(year==2017, 'Homogeneous',' Heterogeneous')
    label = str_interp('minitable-${year}')
    
    table = read_lines('templates/minitable-template-figures2-3.tex') %>% map_chr(function(x) str_interp(x, env=parent.frame(n=2)))
    write_lines(table, str_interp('${out}/protest-participation-heterogeneity-${year}.tex'))
    
  }
}



# Figure 3
make_participation_bar_graphs_heterogeneity_plan = function(data) {
  
  year = 2018
  tl = 0.018
  
  for (planvar in list('noplan', 'plan')) {
    # Select subsample by plan
    plandummy = ifelse(planvar=='plan', 1, 0)
        data1 = data %>% filter(plan_july1_2018_positive==plandummy)
  

    # Heterogeneity
    data1 = data1 %>% mutate(treatment_type = ifelse(treatment_main == 1, 'Treatment', ifelse(treatment_subway == 1, 'Placebo', 'Pure control')))
    takeup1 = data1 %>% mutate(treatment_type2 = ifelse(treatment_type == 'Treatment', 'Treatment', 'Control')) 
    takeup2 = data1 %>% mutate(treatment_type2 = ifelse(treatment_type == 'Treatment', 'Treatment', 'Control')) 
    
    outcome_var = str_interp('participate_july1_${year}')
    
    takeup2$treatment_cell_tier_1 = as.numeric(takeup2$approximate_treatment_cell_tier==0.01)
    takeup2$treatment_cell_tier_0 = as.numeric(takeup2$approximate_treatment_cell_tier==0)
    
    
    # Calculate p-values
    # P all
    formula = as.formula(str_interp('get(outcome_var)~treatment|treatment_cell|0|treatment_cell'))
    model = felm(formula, data=takeup2, weights=takeup2$weight)
    hyp = linearHypothesis(model, c("treatment = 0"), test='F', singular.ok = TRUE)
    pall = hyp$`Pr(>F)`[2] %>% formatP(latex=FALSE,p=TRUE)
    
    # P treatment intensity
    if (planvar=='noplan'){
      formula = as.formula(str_interp('get(outcome_var)~treatment_cell_tier_1:treatment+treatment_cell_tier_50:treatment+treatment_cell_tier_75:treatment|treatment_cell|0|treatment_cell'))
      model = felm(formula, data=takeup2, weights=takeup2$weight)
      hyp = linearHypothesis(model, c("treatment_cell_tier_1:treatment = 0"), test='F', singular.ok = TRUE)
      p1 = hyp$`Pr(>F)`[2] %>% formatP(latex=FALSE,p=TRUE)
      hyp = linearHypothesis(model, c("treatment:treatment_cell_tier_50 = 0"), test='F', singular.ok = TRUE)
      p2 = hyp$`Pr(>F)`[2] %>% formatP(latex=FALSE,p=TRUE)
      hyp = linearHypothesis(model, c("treatment:treatment_cell_tier_75 = 0"), test='F', singular.ok = TRUE)
      p3 = hyp$`Pr(>F)`[2] %>% formatP(latex=FALSE,p=TRUE)
      hyp = linearHypothesis(model, c("treatment_cell_tier_1:treatment = treatment:treatment_cell_tier_50"), test='F', singular.ok = TRUE)
      p4 = hyp$`Pr(>F)`[2] %>% formatP(latex=TRUE,p=TRUE)
      hyp = linearHypothesis(model, c("treatment_cell_tier_1:treatment = treatment:treatment_cell_tier_75"), test='F', singular.ok = TRUE)
      p5 = hyp$`Pr(>F)`[2] %>% formatP(latex=TRUE,p=TRUE)
      hyp = linearHypothesis(model, c("treatment:treatment_cell_tier_50 = treatment:treatment_cell_tier_75"), test='F', singular.ok = TRUE)
      p6 = hyp$`Pr(>F)`[2] %>% formatP(latex=TRUE,p=TRUE)
    } else {
      formula = as.formula(str_interp('get(outcome_var)~treatment_cell_tier_50:treatment+treatment_cell_tier_75:treatment|0|0|treatment_cell'))
      model = felm(formula, data=takeup2, weights=takeup2$weight) 
      p1 = NA
      hyp = linearHypothesis(model, c("treatment_cell_tier_50:treatment = 0"), test='F', singular.ok = TRUE)
      p2 = hyp$`Pr(>F)`[2] %>% formatP(latex=FALSE,p=TRUE)
      hyp = linearHypothesis(model, c("treatment:treatment_cell_tier_75 = 0"), test='F', singular.ok = TRUE)
      p3 = hyp$`Pr(>F)`[2] %>% formatP(latex=FALSE,p=TRUE)
      p4 = '\\ensuremath{\\cdot}'
      p5 = '\\ensuremath{\\cdot}'
      hyp = linearHypothesis(model, c("treatment_cell_tier_50:treatment = treatment:treatment_cell_tier_75"), test='F', singular.ok = TRUE)
      p6 = hyp$`Pr(>F)`[2] %>% formatP(latex=TRUE,p=TRUE)
   }    
    
    
  
    # Takeup total
    takeup1 = takeup1 %>%
      group_by(treatment_type2) %>% 
      summarise(mean = weighted.mean(get(outcome_var), w=weight), 
                se = weighted.sd(get(outcome_var), w=weight)/sqrt(n()),
                .groups = 'drop') %>%
      mutate(high = mean+1.96*se, low = mean-1.96*se)
    
    takeup1$approximate_treatment_cell_tier = '0%'  # Note: Name is "0%" instead of "All" to circumvent a bug in ggsignif
    
    # Takeup by treatment cell
    takeup2 = takeup2 %>%
      group_by(treatment_type2, approximate_treatment_cell_tier) %>% 
      summarise(mean = weighted.mean(get(outcome_var), w=weight), 
                se = weighted.sd(get(outcome_var), w=weight)/sqrt(n()),
                .groups = 'drop') %>%
      mutate(high = mean+1.96*se, low = mean-1.96*se,
             approximate_treatment_cell_tier = dplyr::recode(approximate_treatment_cell_tier,
                                                             `0` = '0%',
                                                             `0.01` = '1%',
                                                             `0.5` = '50%',
                                                             `0.75` = '75%'),
             treatment_type2 = factor(treatment_type2, levels=c('Control','Treatment')))
    
    
    # Fill missing and Drop 0%
    takeup2 = takeup2 %>% complete(treatment_type2, approximate_treatment_cell_tier)  #, fill=list(mean = 0, se=0, high=0, low=0))
    takeup2 = takeup2 %>% filter(approximate_treatment_cell_tier!='0%')
    takeup2[is.na(takeup2)] <- 0
    
     # Combine all and split
    df_comb = rbind(takeup1, takeup2)
    df_comb$approximate_treatment_cell_tier = as.factor(df_comb$approximate_treatment_cell_tier)
    

    
    # Plot
    plot = ggplot(df_comb, aes(x = approximate_treatment_cell_tier, y=mean)) + 
      geom_bar(stat='identity', position=position_dodge2(width=0.9, preserve='single'), aes(fill = treatment_type2,  color=treatment_type2, y = mean)) + 
      xlab('Cell treatment intensity') + ylab('Proportion participating') +
      labs(fill = 'Condition') +
      scale_x_discrete("Cell treatment intensity", breaks = c("0%", "1%", "50%", "75%"),
                                                   labels = c("all", "1%", "50%", "75%"),
                                                   limits = c("0%", "skip", "1%", "50%", "75%")) +
      geom_vline(aes(xintercept=2),linetype="dashed",colour="black",size=1) +
      expand_limits(y = c(0, 0.5)) +
      guides(color=FALSE) + # Hide legend for outer line of geom_bar
      theme_two
    if (planvar == 'plan') {
      plot = plot + 
        geom_signif(annotation=pall, xmin=1-0.25, xmax=1+0.25, y_position=0.37, tip_length = tl, textsize=5) +
        geom_signif(annotation=p1, xmin=3-0.25, xmax=3+0.25, y_position=0.13, tip_length = tl, textsize=5) +
        geom_signif(annotation=p2, xmin=4-0.25, xmax=4+0.25, y_position=0.225, tip_length = tl, textsize=5) +
        geom_signif(annotation=p3, xmin=5-0.25, xmax=5+0.25, y_position=0.45, tip_length = tl, textsize=5)
    } else {
      plot = plot + 
        geom_signif(annotation=pall, xmin=1-0.25, xmax=1+0.25, y_position=0.075, tip_length = tl, textsize=5) +
        geom_signif(annotation=p1, xmin=3-0.25, xmax=3+0.25, y_position=0.03, tip_length = tl, textsize=5) +
        geom_signif(annotation=p2, xmin=4-0.25, xmax=4+0.25, y_position=0.06, tip_length = tl, textsize=5) +
        geom_signif(annotation=p3, xmin=5-0.25, xmax=5+0.25, y_position=0.095, tip_length = tl, textsize=5)}

    ggsave(str_interp('${out}/protest-participation-heterogeneity-${year}-${planvar}.pdf'))
    

    
    # Create mini-table new
    descriptor = ifelse(year==2017, 'Homogeneous',' Heterogeneous')
    label = str_interp('minitable-${year}-${planvar}')
    
    table = read_lines('templates/minitable-template-figures2-3.tex') %>% map_chr(function(x) str_interp(x, env=parent.frame(n=2)))
    write_lines(table, str_interp('${out}/protest-participation-heterogeneity-${year}-${planvar}.tex'))
    
  }
}




# =================================  TABLES ==================================# 

# Table 1
make_participation_table = function(data, measure) {
  # Panel A: Average treatment effect
  formula1 = as.formula(str_interp('participate_july1_2017~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model1 = felm(formula1, data=data, weights=data$weight)
  formula2 = as.formula(str_interp('participate_july1_2017~treatment_main+treatment_main:gender+gender+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model2 = felm(formula2, data=data, weights=data$weight)
  formula3 = as.formula(str_interp('participate_july1_2018~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model3 = felm(formula3, data=data, weights=data$weight)
  formula4 = as.formula(str_interp('participate_july1_2018~treatment_main+treatment_main:gender+gender+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model4 = felm(formula4, data=data, weights=data$weight)
  
  formula5 = as.formula(str_interp('plan_july1_2017_pos~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model5 = felm(formula5, data=data, weights=data$weight)
  formula6 = as.formula(str_interp('plan_july1_2017_pos~treatment_main+treatment_main:gender+gender+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model6 = felm(formula6, data=data, weights=data$weight)
  formula7 = as.formula(str_interp('plan_july1_2018_positive~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model7 = felm(formula7, data=data, weights=data$weight)
  formula8 = as.formula(str_interp('plan_july1_2018_positive~treatment_main+treatment_main:gender+gender+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model8 = felm(formula8, data=data, weights=data$weight)

  
  empty_model = model1
  empty_model$beta[1:2] = c(NA, NA)
  empty_model$cse[1:2] = c(NA, NA)
  empty_model$N = c(NA)
  
  output_average = stargazer(list(model1, model2, model3, model4, empty_model, model7, model8),   # model6, model7 not shown
                             omit = c('gender','predicted'),
                             covariate.labels = c('Treatment'),
                             title = 'Treatment effects: protest participation and plans',
                             label = str_interp('t:participation-${measure}'),
                             star.char = '')
  
  # Panel B: Heterogeneity
  data$approximate_treatment_cell_tier = relevel(data$approximate_treatment_cell_tier, ref=2)
  var = ifelse(measure=='empirical', 'treatment_cell_tier', 'approximate_treatment_cell_tier')
  formula1 = as.formula(str_interp('participate_july1_2017~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model1 = felm(formula1, data=data, weights=data$weight)
  formula2 = as.formula(str_interp('participate_july1_2017~treatment_main+treatment_main:${var}+treatment_main:gender+gender+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model2 = felm(formula2, data=data, weights=data$weight)
  formula3 = as.formula(str_interp('participate_july1_2018~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model3 = felm(formula3, data=data, weights=data$weight)
  formula4 = as.formula(str_interp('participate_july1_2018~treatment_main+treatment_main:${var}+treatment_main:gender+gender+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model4 = felm(formula4, data=data, weights=data$weight)
  
  formula5 = as.formula(str_interp('plan_july1_2017_pos~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model5 = felm(formula5, data=data, weights=data$weight)
  formula6 = as.formula(str_interp('plan_july1_2017_pos~treatment_main+treatment_main:${var}+treatment_main:gender+gender+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model6 = felm(formula6, data=data, weights=data$weight)
  formula7 = as.formula(str_interp('plan_july1_2018_positive~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model7 = felm(formula7, data=data, weights=data$weight)
  formula8 = as.formula(str_interp('plan_july1_2018_positive~treatment_main+treatment_main:${var}+treatment_main:gender+gender+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model8 = felm(formula8, data=data, weights=data$weight)
  
  
  
  
  control = data %>% filter(treatment_main==0)
  control_means_2017 = weighted.mean(control$participate_july1_2017, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  control_sds_2017 = weighted.sd(control$participate_july1_2017, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_means_2017 = weighted.mean(data$participate_july1_2017, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_sds_2017 = weighted.sd(data$participate_july1_2017, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  control_means_2018 = weighted.mean(control$participate_july1_2018, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  control_sds_2018 = weighted.sd(control$participate_july1_2018, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_means_2018 = weighted.mean(data$participate_july1_2018, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_sds_2018 = weighted.sd(data$participate_july1_2018, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)

  control_means_2017_plan = weighted.mean(control$plan_july1_2017_pos, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  control_sds_2017_plan = weighted.sd(control$plan_july1_2017_pos, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_means_2017_plan = weighted.mean(data$plan_july1_2017_pos, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_sds_2017_plan = weighted.sd(data$plan_july1_2017_pos, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  control_means_2018_plan = weighted.mean(control$plan_july1_2018_positive, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  control_sds_2018_plan = weighted.sd(control$plan_july1_2018_positive, control$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_means_2018_plan = weighted.mean(data$plan_july1_2018_positive, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  all_sds_2018_plan = weighted.sd(data$plan_july1_2018_positive, data$weight, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
  
    
  control_mean = c(rep(control_means_2017, 2), rep(control_means_2018, 2), NA, rep(control_means_2018_plan, 2))
  control_sd = c(rep(control_sds_2017, 2), rep(control_sds_2018, 2), NA, rep(control_sds_2018_plan, 2))
  all_mean = c(rep(all_means_2017, 2), rep(all_means_2018, 2), NA, rep(all_means_2018_plan, 2))
  all_sd = c(rep(all_sds_2017, 2), rep(all_sds_2018, 2), NA, rep(all_sds_2018_plan, 2))
  
  paren = ifelse(title_weight_tag==' (reweighted sample)', str_interp('(${measure} intensity, reweighted sample)'),
                 str_interp('(${measure} intensity${title_weight_tag})'))
  

  empty_model = model1
  empty_model$beta[1:5] = c(NA, NA, NA, NA, NA)
  empty_model$cse[1:5] = c(NA, NA, NA, NA, NA)
  empty_model$N = c(NA)
  
  output_heterogeneity = stargazer(list(model1, model2, model3, model4, empty_model, model7, model8),   # model6, model7 not shown
                                   omit = c( 'Constant', 'predicted', 'tier0$', 'gender'),
                                   covariate.labels = c('Treatment',
                                                        'Treatment $\\times$ 50\\% intensity',
                                                        'Treatment $\\times$ 75\\% intensity'),
                                   omit.stat = c('adj.rsq', 'ser', 'f', 'rsq', 'aic','ll'),
                                   add.lines = list(
                                     c('DV mean (control grp.)', control_mean),
                                     c('DV std. dev. (control grp.)', control_sd),
                                     c('DV mean (all)', all_mean),
                                     c('DV std. dev. (all)', all_sd),
                                     c('Gender controls', 'No', 'Yes', 'No', 'Yes', '', 'No', 'Yes')),
                                   style = "aer", omit.table.layout='n',
                                   star.char = '') %>% 
    star_notes_tex(note = str_interp("Panel~A presents estimated coefficients from regressions of protest turnout (or planned turnout) on the individual treatment indicator. Panel~B presents estimated coefficients from regressions of protest turnout (or planned turnout) on the individual treatment indicator interacted with major$\times$cohort cell treatment intensity bin indicators (and lower-order terms). Results are shown for 2017 protest turnout (columns~1--2), 2018 protest turnout (columns~3--4), and 2018 planned protest turnout (columns~5--6). Columns~1,~3, and~5 include major$\times$cohort cell fixed effects; in addition, columns~2,~4, and~6 include the interaction between individual treatment status and a gender indicator. Standard errors (reported in parentheses) are clustered at the major$\times$cohort cell level."))
  
  # Combine Panel A and Panel B
  output_average[11] = str_interp(paste('& \\multicolumn{4}{c}{Participation} & \\multicolumn{1}{c}{\\white{xx}} & \\multicolumn{2}{c}{Plans to participate} \\\\',
                                        '\\cmidrule(rr){2-5} \\cmidrule(rr){7-8} ',
                                        '& 2017 & 2017 & 2018 & 2018 & & 2018 & 2018 \\\\'))
  
  
  output_average[12] = "\\cmidrule(rr){2-2} \\cmidrule(rr){3-3} \\cmidrule(rr){4-4} \\cmidrule(rr){5-5} \\cmidrule(rr){7-7} \\cmidrule(rr){8-8}"
  output_average[13] = " & (1) & (2) & (3) & (4) & & (5) & (6)\\\\ "
  output = c(output_average[1:8], output_average[11:14], 
             '\\multicolumn{8}{l}{\\textbf{Panel A}: \\textit{Average treatment effect}} \\\\',
             '\\midrule',
             output_average[15:18],
             '\\multicolumn{8}{l}{\\textbf{Panel B}: \\textit{Heterogeneity by cell treatment intensity}} \\\\',
             '\\midrule',
             output_heterogeneity[15:length(output_heterogeneity)])
  
  
  output[which(str_detect(output, 'begin\\{tablenotes\\}'))] = str_replace(output[which(str_detect(output, 'begin\\{tablenotes\\}'))], 'begin\\{tablenotes\\}', 'begin\\{tablenotes\\}[flushleft]')
  
  #Make table small
  output[4] = paste(output[4], '\\small')

  writeLines(output, con = str_interp('${out}/participation-${measure}.tex'))
}




# Table 2
make_outcomes_table = function(data, measure) {
  # Average
  formula1 = as.formula(str_interp('az_polpreferences_post17~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model1 = felm(formula1, data=data, weights=data$weight)
  formula2 = as.formula(str_interp('az_polpreferences_pre18~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model2 = felm(formula2, data=data, weights=data$weight)
  formula3 = as.formula(str_interp('az_polbeliefs_post17~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model3 = felm(formula3, data=data, weights=data$weight)
  formula4 = as.formula(str_interp('az_polbeliefs_pre18~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model4 = felm(formula4, data=data, weights=data$weight)
  formula5 = as.formula(str_interp('az_secbeliefs_post17~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model5 = felm(formula5, data=data, weights=data$weight)
  formula6 = as.formula(str_interp('az_secbeliefs_pre18~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model6 = felm(formula6, data=data, weights=data$weight)
  formula7 = as.formula(str_interp('newfriendship_2018~treatment_main+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model7 = felm(formula7, data=data, weights=data$weight)
  
  output_average = stargazer(list(model7, model1, model2, model3, model4, model5, model6),
                             omit = c('gender','predicted'),
                             covariate.labels = c('Treatment'),
                             title = 'Mechanisms: political beliefs, preferences, beliefs about others, and new friendships',
                             label = str_interp('t:outcomes-${measure}'),
                             star.char = '')
  
  # Heterogeneity
  data$approximate_treatment_cell_tier = relevel(data$approximate_treatment_cell_tier, ref=2)
  var = ifelse(measure=='empirical', 'treatment_cell_tier', 'approximate_treatment_cell_tier')
  formula1 = as.formula(str_interp('az_polpreferences_post17~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model1 = felm(formula1, data=data, weights=data$weight)
  formula2 = as.formula(str_interp('az_polpreferences_pre18~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model2 = felm(formula2, data=data, weights=data$weight)
  formula3 = as.formula(str_interp('az_polbeliefs_post17~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model3 = felm(formula3, data=data, weights=data$weight)
  formula4 = as.formula(str_interp('az_polbeliefs_pre18~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model4 = felm(formula4, data=data, weights=data$weight)
  formula5 = as.formula(str_interp('az_secbeliefs_post17~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model5 = felm(formula5, data=data, weights=data$weight)
  formula6 = as.formula(str_interp('az_secbeliefs_pre18~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model6 = felm(formula6, data=data, weights=data$weight)
  formula7 = as.formula(str_interp('newfriendship_2018~treatment_main+treatment_main:${var}+predicted_protest_participation|treatment_cell|0|treatment_cell'))
  model7 = felm(formula7, data=data, weights=data$weight)
  
  control = data %>% filter(treatment_main==0)
  
  
  
  w = control$weight
  control_means = list(control$newfriendship_2018,
                       control$az_polpreferences_post17, control$az_polpreferences_pre18,
                       control$az_polbeliefs_post17, control$az_polbeliefs_pre18,
                       control$az_secbeliefs_post17, control$az_secbeliefs_pre18) %>% map_chr(formatted_mean_weighted)

  control_sds = c(weighted.sd(control$newfriendship_2018, control$weight, na.rm=T),
                  weighted.sd(control$az_polpreferences_post17, control$weight, na.rm=T),
                  weighted.sd(control$az_polpreferences_pre18, control$weight, na.rm=T),
                  weighted.sd(control$az_polbeliefs_post17, control$weight, na.rm=T),
                  weighted.sd(control$az_polbeliefs_pre18, control$weight, na.rm=T),
                  weighted.sd(control$az_secbeliefs_post17, control$weight, na.rm=T),
                  weighted.sd(control$az_secbeliefs_pre18, control$weight, na.rm=T)) %>% round(3) %>% sprintf("%.3f", .)
  
  

  w = data$weight
  all_means = list(data$newfriendship_2018,
                   data$az_polpreferences_post17, data$az_polpreferences_pre18,
                   data$az_polbeliefs_post17, data$az_polbeliefs_pre18,
                   data$az_secbeliefs_post17, data$az_secbeliefs_pre18) %>% map_chr(formatted_mean_weighted)

  
  all_sds = c(weighted.sd(data$newfriendship_2018, data$weight, na.rm=T),
              weighted.sd(data$az_polpreferences_post17, data$weight, na.rm=T),
              weighted.sd(data$az_polpreferences_pre18, data$weight, na.rm=T),
              weighted.sd(data$az_polbeliefs_post17, data$weight, na.rm=T),
              weighted.sd(data$az_polbeliefs_pre18, data$weight, na.rm=T),
              weighted.sd(data$az_secbeliefs_post17, data$weight, na.rm=T),
              weighted.sd(data$az_secbeliefs_pre18, data$weight, na.rm=T)) %>% round(3) %>% sprintf("%.3f", .)
  
  
  paren = ifelse(title_weight_tag==' (reweighted sample)', str_interp('(${measure} intensity, reweighted sample)'),
                 str_interp('(${measure} intensity${title_weight_tag})'))
  
  output_heterogeneity = stargazer(list(model7, model1, model2, model3, model4, model5, model6), 
                                   omit = c( 'Constant', 'predicted', 'tier0$', 'gender'),
                                   covariate.labels = c('Treatment',
                                                        'Treatment $\\times$ 50\\% intensity',
                                                        'Treatment $\\times$ 75\\% intensity'),
                                   omit.stat = c('adj.rsq', 'ser', 'f', 'rsq', 'aic','ll'),
                                   add.lines = list(
                                     c('DV mean (control grp.)', control_means),
                                     c('DV std. dev. (control grp.)', control_sds),
                                     c('DV mean (all)', all_means),
                                     c('DV std. dev. (all)', all_sds)),
                                   style = "aer", omit.table.layout='n',
                                   star.char = '') %>% 
    star_notes_tex(note = str_interp("Panel~A presents estimated coefficients from regressions of new friendships, indices of preferences, political beliefs, and beliefs about others on the individual treatment indicator. Panel~B presents estimated coefficients from regressions of new friendships, indices of preferences, political beliefs, and beliefs about others on the individual treatment indicator interacted with major$\times$cohort cell treatment intensity bin indicators (and lower-order terms). Results are shown for new friendships reported in July 2018 (column~1); for July 2017 preferences, beliefs, and beliefs about others (columns~2,~4,~and~6); and for June 2018 preferences, beliefs, and beliefs about others (columns~3,~5,~and~7).  All regressions include major$\times$cohort cell fixed effects. Standard errors (reported in parentheses) are clustered at the major$\times$cohort cell level."))
  


    output_average[11] = str_interp(paste('& \\multicolumn{1}{c}{New friendships} & \\multicolumn{2}{c}{Political preferences} & \\multicolumn{2}{c}{Political beliefs} & \\multicolumn{2}{c}{Beliefs about others} \\\\',
                                        '\\cmidrule(rr){2-2} \\cmidrule(rr){3-4} \\cmidrule(rr){5-6} \\cmidrule(rr){7-8}',
                                        '& 2018 & 2017 & 2018 & 2017 & 2018 & 2017 & 2018 \\\\',
                                        '\\cmidrule(rr){2-2} \\cmidrule(rr){3-3} \\cmidrule(rr){4-4} \\cmidrule(rr){5-5} \\cmidrule(rr){6-6} \\cmidrule(rr){7-7} \\cmidrule(rr){8-8}'))
  output = c(output_average[1:8], output_average[11:13], 
             '\\multicolumn{8}{l}{\\textbf{Panel A}: \\textit{Average treatment effect}} \\\\',
             '\\midrule',
             output_average[14:17],
             '\\multicolumn{8}{l}{\\textbf{Panel B}: \\textit{Heterogeneity by cell treatment intensity}} \\\\',
             '\\midrule',
             output_heterogeneity[14:length(output_heterogeneity)])
 
  #Make table small
  output[4] = paste(output[4], '\\small')
  
   
  writeLines(output, con = str_interp('${out}/outcomes-${measure}.tex'))
}




# ===================================  RUN ====================================# 


# Run
run_models = function(data) {
  if (out!='reweight' & out!='reweight-merge') {
    # Figure 1:
    make_participation_bar_graphs(data)
    # Figure 2: 
    make_participation_bar_graphs_heterogeneity(data)
    # Figure 3: 
    make_participation_bar_graphs_heterogeneity_plan(data)
  }
}


main = function() {
  merge_cells <<- F
  data = prepare_data()
  out <<- 'minimal'
  title_weight_tag <<- ''
  note_weight_tag <<- ''
  label_weight_tag <<- ''
  dir.create(out)
  dir.create('data')
  constrained_sample = data[!is.na(data$az_polbeliefs_post18) & !is.na(data$az_polbeliefs_pre18) & !is.na(data$plan_july1_2018_positive),]
  # Table 1:
  make_participation_table(constrained_sample, 'target')
  # Table 3:
  make_outcomes_table(constrained_sample, 'target')

  # Run part to create figures
  run_models(constrained_sample)
  
}

main()




